## 港股列表

接口：hk_basic

描述：获取港股列表信息

数量：单次可提取全部在交易的港股列表数据

积分：用户需要至少2000积分才可以调取，具体请参阅积分获取办法 

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | N | TS代码 |
| list_status | str | N | 上市状态 L上市 D退市 P暂停上市 ，默认L |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | Y |  |
| name | str | Y | 股票简称 |
| fullname | str | Y | 公司全称 |
| enname | str | Y | 英文名称 |
| cn_spell | str | Y | 拼音 |
| market | str | Y | 市场类别 |
| list_status | str | Y | 上市状态 |
| list_date | str | Y | 上市日期 |
| delist_date | str | Y | 退市日期 |
| trade_unit | float | Y | 交易单位 |
| isin | str | Y | ISIN代码 |
| curr_type | str | Y | 货币代码 |

接口示例

```python
pro = ts.pro_api()

#获取全部可交易股票基础信息
df = pro.hk_basic()

#获取全部退市股票基础信息
df = pro.hk_basic(list_status='D')
```

数据示例

```python
ts_code             name  ...          isin curr_type
0     00001.HK               长和  ...  KYG217651051       HKD
```